
0.4.13 (2016-12-12)
###################

Changes since 0.4.12 (2016-12-06).

Bug Fixes
$$$$$$$$$

* closes `#390 <https://bitbucket.org/biocommons/hgvs/issues/390/>`_: fix missing HGVSError import in variantmapper [`9e3bee72a349 <https://bitbucket.org/biocommons/hgvs/commits/9e3bee72a349>`_]
